@@ -1,23 +1,10 @@
-/* This file is part of libkdbusaddons
+/*
+    This file is part of libkdbusaddons
 
-   Copyright (c) 2011 David Faure <faure@kde.org>
-   Copyright (c) 2011 Kevin Ottens <ervin@kde.org>
+    SPDX-FileCopyrightText: 2011 David Faure <faure@kde.org>
+    SPDX-FileCopyrightText: 2011 Kevin Ottens <ervin@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Lesser General Public
-   License as published by the Free Software Foundation; either
-   version 2.1 of the License, or (at your option) version 3, or any
-   later version accepted by the membership of KDE e.V. (or its
-   successor approved by the membership of KDE e.V.), which shall
-   act as a proxy defined in Section 6 of version 3 of the license.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Lesser General Public License for more details.
-
-   You should have received a copy of the GNU Lesser General Public
-   License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #ifndef KDBUSSERVICE_H
@@ -25,6 +12,7 @@
 
 #include <QObject>
 #include <QUrl>
+#include <memory>
 
 #include <kdbusaddons_export.h>
 
@@ -93,7 +81,10 @@ class KDBUSADDONS_EXPORT KDBusService : public QObject
     Q_OBJECT
 
 public:
-    /** Options to control the behaviour of KDBusService */
+    /**
+     * Options to control the behaviour of KDBusService
+     * @see StartupOptions
+     */
     enum StartupOption {
         /**
          * Indicates that only one instance of this application should ever exist.
@@ -130,6 +121,9 @@ public:
     };
     Q_ENUM(StartupOption)
 
+    /**
+     * Stores a combination of #StartupOption values.
+     */
     Q_DECLARE_FLAGS(StartupOptions, StartupOption)
     Q_FLAG(StartupOptions)
 
@@ -226,9 +220,15 @@ Q_SIGNALS:
      *        commandLineParser->parse(arguments); // same QCommandLineParser instance as the one used in main()
      *        handleCmdLine(workingDirectory); // shared method with main(), which uses commandLineParser to handle options and positional arguments
      *    }
-     *    // and for GUI applications, also terminate startup notification and activate the mainwindow:
-     *    KStartupInfo::setNewStartupId(mainWindow, KStartupInfo::startupId());
-     *    KWindowSystem::forceActiveWindow(mainWindow->winId());
+     *
+     *
+     *    For GUI applications on X11 , also terminate startup notification and activate the mainwindow:
+     *    The startup ID will exposed be via QX11Extras::nextStartupId
+     *
+     *    If an existing window is to be raised, call:
+     *    KStartupInfo::setNewStartupId(mainWindow, QX11Extras::nextStartupId);
+     *    mainWindow->raise();
+     *
      * @endcode
      *
      * If you're using the builtin handling of @c --help and @c --version in QCommandLineParser,
@@ -274,7 +274,7 @@ private:
     friend class KDBusServiceExtensionsAdaptor;
 
 private:
-    KDBusServicePrivate *const d;
+    std::unique_ptr<KDBusServicePrivate> const d;
 };
 
 Q_DECLARE_OPERATORS_FOR_FLAGS(KDBusService::StartupOptions)
